@@ -4,7 +4,6 @@ App::DBBrowser::OptDB;
 use warnings;
 use strict;
 use 5.008003;
-no warnings 'utf8';
 
 use File::Spec::Functions qw( catfile );
 
@@ -12,8 +11,6 @@ use Term::Choose       qw( choose );
 use Term::Choose::Util qw( choose_a_subset settings_menu );
 use Term::Form         qw();
 
-use if $^O eq 'MSWin32', 'Win32::Console::ANSI';
-
 use App::DBBrowser::Auxil;
 use App::DBBrowser::DB;
 
